#!/usr/bin/env python3

import sys
import subprocess
#import re

def get_ps():

    #if sys.platform == 'darwin':
    #    cmd='ps -A -o stat,uid,ppid,pid,user,etime,command'
    #if sys.platform == 'linux' or sys.platform == 'linux2':
    #    cmd='ps -ef'

    cmd='ps -A -o stat,uid,ppid,pid,user,etime,command'

    p = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
    output, err = p.communicate()
    exit_code = p.wait()
    if (exit_code != 0):
        print('Error: ' + str(err) + ' ' + str(output))
        return exit_code

    multilines = output.splitlines()
    defunct_data = {}
    odict = {}
    Dct = {}
    count = 0

    for line in multilines:
       count += 1
       line = line.decode('utf-8')
       odict[count] = line
       #print(str(count) + ': ' + str(line))

    number_of_procs = len(odict)
    number_of_defunct = 0

    for num in odict:
        line = odict[num]

        #linux
        #if re.search(r'<defunct>', line):
        #    number_of_defunct += 1
        #    defunct_data[number_of_defunct] = str(line)
        #defunct_data[1] = '503 19591 19580   0  6:57PM ttys010    0:00.00 defunct'

        #mac
        if line.startswith('Z'):
            number_of_defunct += 1
            #defunct_data[number_of_defunct] = str(line)
            _key = 'defunct' + str(number_of_defunct)
            defunct_data[_key] = str(line)

    Dct['procs'] = number_of_procs
    Dct['defunct'] = number_of_defunct
    Dct.update(defunct_data)
    return Dct

if __name__ == '__main__':

    run = get_ps()
    print(run)

#>>> import sys
#>>> sys.path.append('/ufs/guido/lib/python')





# -*- coding: utf-8 -*-

"""setup.py: setuptools control."""

from setuptools import setup

setup(
    name = "sentinel-server",
    packages = ["sentinel_server"],
    entry_points = {
        "console_scripts": ['sentinel = sentinel_server.sentinel:main']
        },
    version = '1.8.4',
    description = "sentinel command and daemon",
    long_description = "Python command line tool for administration of sentinel.",
    author = "Karl Rink",
    author_email = "karl@rink.us",
    url = "https://gitlab.com/krink/sentinel",
    install_requires = [],
    include_package_data=True,
    package_data={'': ['db/manuf',
        'modules/ps/ps.py',
        'modules/hv/kvm.py',
        'modules/gitegridy/gitegridy.py',
        'modules/ipwhois/ipwhois.py',
        ]},
    )





#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import sys
import requests

def ipwhois_iplocation(ipaddr):
    """get: iplocation.net/?ip=."""
    # https://api.iplocation.net/?ip=8.8.8.8
    _url = "https://api.iplocation.net/?ip=" + str(ipaddr)
    response = requests.get(_url)
    return response.json()


def ipwhois_ipapi(ipaddr):
    """get: ip-api.com/json/24.48.0.1"""
    # http://ip-api.com/json/24.48.0.1
    _url = "http://ip-api.com/json/" + str(ipaddr)
    response = requests.get(_url)
    return response.json()


if __name__ == '__main__':

    if sys.argv[1:]:

        ip = sys.argv[1]

        whois = ipwhois_iplocation(ip)

        print(whois)


    else:
        print('Usage: ' + sys.argv[0] + ' ip.addr')


